@@ -10,9 +10,9 @@ import warnings
 import click
 import dask
 from dask.utils import ignoring
+from dask.system import CPU_COUNT
 from distributed import Nanny, Worker
 from distributed.security import Security
-from distributed.system import CPU_COUNT
 from distributed.cli.utils import check_python_3, install_signal_handlers
 from distributed.comm import get_address_host_port
 from distributed.preloading import validate_preload_argv
@@ -20,6 +20,7 @@ from distributed.proctitle import (
     enable_proctitle_on_children,
     enable_proctitle_on_current,
 )
+from distributed.utils import deserialize_for_cli
 
 from toolz import valmap
 from tornado.ioloop import IOLoop, TimeoutError
@@ -359,6 +360,11 @@ def main(
     with ignoring(TypeError, ValueError):
         name = int(name)
 
+    if "DASK_INTERNAL_INHERIT_CONFIG" in os.environ:
+        config = deserialize_for_cli(os.environ["DASK_INTERNAL_INHERIT_CONFIG"])
+        # Update the global config given priority to the existing global config
+        dask.config.update(dask.config.global_config, config, priority="old")
+
     nannies = [
         t(
             scheduler,
