@@ -11,15 +11,16 @@ from toolz import first
 from tornado import gen
 from tornado.httpclient import AsyncHTTPClient, HTTPRequest
 
+import dask
 from dask.core import flatten
 from distributed.utils import tokey, format_dashboard_link
 from distributed.client import wait
 from distributed.metrics import time
 from distributed.utils_test import gen_cluster, inc, dec, slowinc, div, get_cert
-from distributed.dashboard.worker import Counters, BokehWorker
-from distributed.dashboard.scheduler import (
-    applications,
-    BokehScheduler,
+from distributed.dashboard.worker import BokehWorker
+from distributed.dashboard.components.worker import Counters
+from distributed.dashboard.scheduler import applications, BokehScheduler
+from distributed.dashboard.components.scheduler import (
     SystemMonitor,
     Occupancy,
     StealingTimeSeries,
@@ -32,8 +33,9 @@ from distributed.dashboard.scheduler import (
     ProcessingHistogram,
     NBytesHistogram,
     WorkerTable,
-    GraphPlot,
+    TaskGraph,
     ProfileServer,
+    MemoryByKey,
 )
 
 from distributed.dashboard import scheduler
@@ -70,7 +72,7 @@ def test_simple(c, s, a, b):
 
 @gen_cluster(client=True, worker_kwargs=dict(services={"dashboard": BokehWorker}))
 def test_basic(c, s, a, b):
-    for component in [SystemMonitor, Occupancy, StealingTimeSeries]:
+    for component in [TaskStream, SystemMonitor, Occupancy, StealingTimeSeries]:
         ss = component(s)
 
         ss.update()
@@ -305,6 +307,11 @@ def test_WorkerTable(c, s, a, b):
     wt = WorkerTable(s)
     wt.update()
     assert all(wt.source.data.values())
+    assert all(
+        not v or isinstance(v, (str, int, float))
+        for L in wt.source.data.values()
+        for v in L
+    ), {type(v).__name__ for L in wt.source.data.values() for v in L}
     assert all(len(v) == 2 for v in wt.source.data.values())
 
     nthreads = wt.source.data["nthreads"]
@@ -438,8 +445,8 @@ def test_WorkerTable_custom_metric_overlap_with_core_metric(c, s, a, b):
 
 
 @gen_cluster(client=True)
-def test_GraphPlot(c, s, a, b):
-    gp = GraphPlot(s)
+def test_TaskGraph(c, s, a, b):
+    gp = TaskGraph(s)
     futures = c.map(inc, range(5))
     total = c.submit(sum, futures)
     yield total
@@ -478,8 +485,8 @@ def test_GraphPlot(c, s, a, b):
 
 
 @gen_cluster(client=True)
-def test_GraphPlot_clear(c, s, a, b):
-    gp = GraphPlot(s)
+def test_TaskGraph_clear(c, s, a, b):
+    gp = TaskGraph(s)
     futures = c.map(inc, range(5))
     total = c.submit(sum, futures)
     yield total
@@ -502,9 +509,9 @@ def test_GraphPlot_clear(c, s, a, b):
 
 
 @gen_cluster(client=True, timeout=30)
-def test_GraphPlot_complex(c, s, a, b):
+def test_TaskGraph_complex(c, s, a, b):
     da = pytest.importorskip("dask.array")
-    gp = GraphPlot(s)
+    gp = TaskGraph(s)
     x = da.random.random((2000, 2000), chunks=(1000, 1000))
     y = ((x + x.T) - x.mean(axis=0)).persist()
     yield wait(y)
@@ -533,12 +540,12 @@ def test_GraphPlot_complex(c, s, a, b):
 
 
 @gen_cluster(client=True)
-def test_GraphPlot_order(c, s, a, b):
+def test_TaskGraph_order(c, s, a, b):
     x = c.submit(inc, 1)
     y = c.submit(div, 1, 0)
     yield wait(y)
 
-    gp = GraphPlot(s)
+    gp = TaskGraph(s)
     gp.update()
 
     assert gp.node_source.data["state"][gp.layout.index[y.key]] == "erred"
@@ -685,3 +692,20 @@ def test_https_support(c, s, a, b):
         body = response.body.decode()
         assert "bokeh" in body.lower()
         assert not re.search("href=./", body)  # no absolute links
+
+
+@gen_cluster(
+    client=True, scheduler_kwargs={"services": {("dashboard", 0): BokehScheduler}}
+)
+async def test_memory_by_key(c, s, a, b):
+    mbk = MemoryByKey(s)
+
+    da = pytest.importorskip("dask.array")
+    x = (da.random.random((20, 20), chunks=(10, 10)) + 1).persist(optimize_graph=False)
+    await x
+
+    y = await dask.delayed(inc)(1).persist()
+
+    mbk.update()
+    assert mbk.source.data["name"] == ["add", "inc"]
+    assert mbk.source.data["nbytes"] == [x.nbytes, sys.getsizeof(1)]
