@@ -1,10 +1,11 @@
-from distributed.protocol.pickle import dumps, loads
-
-import pytest
+from functools import partial
+import gc
+from operator import add
 import weakref
 
-from operator import add
-from functools import partial
+import pytest
+
+from distributed.protocol.pickle import dumps, loads
 
 
 def test_pickle_data():
@@ -42,5 +43,6 @@ def test_pickle_functions():
         wr2 = weakref.ref(func2)
         assert func2(1) == func(1)
         del func, func2
+        gc.collect()
         assert wr() is None
         assert wr2() is None
