@@ -1,5 +1,3 @@
-from __future__ import print_function, division, absolute_import
-
 from contextlib import contextmanager
 import socket
 import sys
@@ -13,6 +11,7 @@ from distributed import Scheduler, Worker, Client, config, default_client
 from distributed.core import rpc
 from distributed.metrics import time
 from distributed.utils_test import (  # noqa: F401
+    cleanup,
     cluster,
     gen_cluster,
     inc,
@@ -175,11 +174,10 @@ def test_tls_cluster(tls_client):
     assert tls_client.security
 
 
-def test_tls_scheduler(security, loop):
-    s = Scheduler(security=security, loop=loop)
-    s.start("localhost")
-    assert s.address.startswith("tls")
-    s.close()
+@pytest.mark.asyncio
+async def test_tls_scheduler(security, cleanup):
+    async with Scheduler(security=security, host="localhost") as s:
+        assert s.address.startswith("tls")
 
 
 if sys.version_info >= (3, 5):
